@@ -4,18 +4,17 @@
 
 package PDL::CCS::IO::FastRaw;
 use PDL::CCS::Version;
+use PDL::CCS::Config qw(ccs_indx);
 use PDL::CCS::Nd;
+use PDL::CCS::IO::Common qw(:intern);
 use PDL;
 use PDL::IO::FastRaw;
 use Carp qw(confess);
 use strict;
 
-our $VERSION = $PDL::CCS::VERSION;
+our $VERSION = '1.22.6';
 our @ISA = ('PDL::Exporter');
-our @EXPORT_OK =
-  (
-   qw(ccs_writefraw ccs_readfraw ccs_mapfraw),
-  );
+our @EXPORT_OK = qw(ccs_writefraw ccs_readfraw ccs_mapfraw);
 our %EXPORT_TAGS =
   (
    Func => [@EXPORT_OK],               ##-- respect PDL conventions (hopefully)
@@ -47,63 +46,6 @@ PDL::CCS::IO::FastRaw - PDL::IO::FastRaw wrappers for PDL::CCS::Nd
 
 =cut
 
-##======================================================================
-## private utilities
-
-## \%ixOpts = _ccsio_opts_ix(\%opts)
-## \%ixOpts = _ccsio_opts_ix(\%opts,\%defaults)
-##  + extracts 'ixX' options from \%opts as 'X' options in \%ixOpts
-sub _ccsio_opts_ix {
-  my $opts = { map {s/^ix//; ($_=>$_[0]{$_})} grep {/^ix/} keys %{$_[0]//{}} };
-  $opts->{$_} //= $_[1]{$_} foreach (keys %{$_[1]//{}});
-  return $opts;
-}
-
-## \%nzOpts = _ccsio_opts_nz(\%opts)
-## \%nzOpts = _ccsio_opts_nz(\%opts,\%defaults)
-##  + extracts 'nzX' options from \%opts as 'X' options in \%nzOpts
-sub _ccsio_opts_nz {
-  my $opts = { map {s/^nz//; ($_=>$_[0]{$_})} grep {/^nz/} keys %{$_[0]//{}} };
-  $opts->{$_} //= $_[1]{$_} foreach (keys %{$_[1]//{}});
-  return $opts;
-}
-
-## \%header = _ccsio_read_header($hfile)
-sub _ccsio_read_header {
-  my $hFile = shift;
-  open(my $hfh, "<$hFile")
-    or confess("_ccsio_read_header(): open failed for header-file $hFile: $!");
-  binmode($hfh,':raw');
-  my ($magic,$pdims,$vdims,$flags) = map {chomp;$_} <$hfh>;
-  close($hfh)
-    or confess("_ccsio_read_header(): close failed for header-file $hFile: $!");
-  return {
-	  magic=>$magic,
-	  pdims=>pdl(long,[split(' ',$pdims)]),
-	  vdims=>pdl(long,[split(' ',$vdims)]),
-	  flags=>$flags,
-	 };
-}
-
-## $bool = _ccsio_write_header(\%header, $hfile)
-sub _ccsio_write_header {
-  my ($header,$hFile) = @_;
-  open(my $hfh, ">$hFile")
-    or confess("_ccsio_read_header(): open failed for header-file $hFile: $!");
-  binmode($hfh,':raw');
-  local $, = '';
-  print $hfh
-    (($header->{magic}//''), "\n",
-     join(' ', $header->{pdims}->list), "\n",
-     join(' ', $header->{vdims}->list), "\n",
-     ($header->{flags} // $PDL::CCS::Nd::CCSND_FLAGS_DEFAULT), "\n",
-    );
-  close($hfh)
-    or confess("_ccsio_write_header(): close failed for header-file $hFile: $!");
-  return 1;
-}
-
-
 ##======================================================================
 ## I/O utilities
 =pod
@@ -143,7 +85,7 @@ sub ccs_writefraw {
   my $nzFile = $opts->{nzFile} // "$fname.nz";
 
   ##-- write header
-  _ccsio_write_header({magic=>(ref($ccs)." $VERSION"), pdims=>$ccs->pdims, vdims=>$ccs->vdims, flags=>$ccs->flags}, $hFile)
+  _ccsio_write_header($ccs, $hFile)
     or confess("ccs_writefraw(): failed to write header-file $hFile: $!");
 
   ##-- write pdls
@@ -181,12 +123,12 @@ Options %opts:
 *PDL::ccs_readfraw = *PDL::CCS::Nd::readfraw = \&ccs_readfraw;
 sub ccs_readfraw {
   shift if (UNIVERSAL::isa($_[0],'PDL') || UNIVERSAL::isa($_[0],'PDL::CCS::Nd'));
-  my ($fname,$opts) = @_;
+  my ($file,$opts) = @_;
 
   ##-- get filenames
-  my $hFile  = $opts->{Header} // "$fname.hdr";
-  my $ixFile = $opts->{ixFile} // "$fname.ix";
-  my $nzFile = $opts->{nzFile} // "$fname.nz";
+  my $hFile  = $opts->{Header} // "$file.hdr";
+  my $ixFile = $opts->{ixFile} // "$file.ix";
+  my $nzFile = $opts->{nzFile} // "$file.nz";
 
   ##-- read header
   my $header = _ccsio_read_header($hFile)
@@ -247,12 +189,12 @@ Component options in %opts, for ${c} in qw(ix nz):
 *PDL::ccs_mapfraw = *PDL::CCS::Nd::mapfraw = \&ccs_mapfraw;
 sub ccs_mapfraw {
   shift if (UNIVERSAL::isa($_[0],'PDL') || UNIVERSAL::isa($_[0],'PDL::CCS::Nd'));
-  my ($fname,$opts) = @_;
+  my ($file,$opts) = @_;
 
   ##-- get filenames
-  my $hFile  = $opts->{Header} // "$fname.hdr";
-  my $ixFile = $opts->{ixFile} // "$fname.ix";
-  my $nzFile = $opts->{nzFile} // "$fname.nz";
+  my $hFile  = $opts->{Header} // "$file.hdr";
+  my $ixFile = $opts->{ixFile} // "$file.ix";
+  my $nzFile = $opts->{nzFile} // "$file.nz";
 
   ##-- get ccs header
   my $header = {
@@ -265,9 +207,9 @@ sub ccs_mapfraw {
       or confess("ccs_mapfraw(): failed to read header-file $hFile: $!");
     $header->{$_} //= $hdr->{$_} foreach (keys %$hdr);
   }
-  $header->{pdims} = PDL->topdl(long,$header->{pdims}) if (!ref($header->{pdims}));
+  $header->{pdims} = PDL->topdl(ccs_indx,$header->{pdims}) if (!ref($header->{pdims}));
   $header->{vdims} = $header->{pdims}->sequence if (!defined($header->{vdims}));
-  $header->{vdims} = PDL->topdl(long,$header->{vdims}) if (!ref($header->{vdims}));
+  $header->{vdims} = PDL->topdl(ccs_indx,$header->{vdims}) if (!ref($header->{vdims}));
 
   ##-- get component options
   my %defaults = (map {($_=>$opts->{$_})} grep {exists($opts->{$_})} qw(Creat Trunc ReadOnly));
@@ -322,10 +264,13 @@ as Perl itself.
 
 =head1 SEE ALSO
 
-perl(1),
-PDL(3perl),
-PDL::IO::FastRaw(3perl),
-PDL::CCS::Nd(3perl),
+L<perl>,
+L<PDL>,
+L<PDL::CCS::Nd>,
+L<PDL::CCS::IO::FITS>,
+L<PDL::CCS::IO::MatrixMarket>,
+L<PDL::CCS::IO::LDAC>,
+...
 
 =cut
 
